#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2021 Anna Lea
# SPDX-FileCopyrightText: © 2023 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Neverending Nightmares
# send your bug reports to contact@dotslashplay.it
###

script_version=20230819.2

GAME_ID='neverending-nightmares'
GAME_NAME='Neverending Nightmares'

ARCHIVE_BASE_0='neverending_nightmares_3_3_22468_41851.sh'
ARCHIVE_BASE_0_MD5='4ab28bf5862dc35e6a821e1aabc3e41a'
ARCHIVE_BASE_0_TYPE='mojosetup'
ARCHIVE_BASE_0_SIZE='390000'
ARCHIVE_BASE_0_VERSION='3.3.22468-gog41851'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/neverending_nightmares'

CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_LIBS_BIN_FILES='
OpenAL-MOB.so'
CONTENT_GAME_BIN_FILES='
nightmare'
CONTENT_GAME_DATA_FILES='
controller.vdf
*.itap'

APP_MAIN_EXE='nightmare'
APP_MAIN_ICON='../support/icon.png'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libasound.so.2
libc.so.6
libcurl.so.4
libGL.so.1
libGLU.so.1
libgtk-x11-2.0.so.0
libidn.so.11
libopenal.so.1
libstdc++.so.6
libudev.so.1
libuuid.so.1'

# Load common functions

target_version='2.26'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
